Qt Desktop GUI User Guide
=========================

.. deprecated::
   This guide has been superseded by the structured tutorial.

See :doc:`/tutorials/routine/gui_desktop/index` for the complete GUI guide,
including launching, workflow pages, and presets.
